@@ -27,9 +27,9 @@ class Network(object):
 		try: 
 			error = info["error"]
 			if "rate limit exceeded" in str(error["title"]).lower():
-				return r3sponse.error(f"(https://ipinfo.io/json) {error['title']}: {error['message'].replace('  ',' ')} Define environment variable $IPINFO_API_KEY to specify an api key.")
+				return Response.error(f"(https://ipinfo.io/json) {error['title']}: {error['message'].replace('  ',' ')} Define environment variable $IPINFO_API_KEY to specify an api key.")
 			else:
-				return r3sponse.error(f"(https://ipinfo.io/json) {error['title']}: {error['message'].replace('  ',' ')}")
+				return Response.error(f"(https://ipinfo.io/json) {error['title']}: {error['message'].replace('  ',' ')}")
 		except KeyError: a=1
 
 		# set.
@@ -38,22 +38,22 @@ class Network(object):
 			del(info["ip"])
 			info["public_ip"] = x
 		except KeyError: 
-			return r3sponse.error("Unable to fetch netork info.")
+			return Response.error("Unable to fetch netork info.")
 		try: info["private_ip"] = self.__get_private_ip__()
 		except: info["private_ip"] = "unkown"
 		try: info["hostname"] = socket.gethostname()
 		except: info["hostname"] = "unkown"
 
 		# success.
-		return r3sponse.success(f"Successfully retrieved the network information.", info)
+		return Response.success(f"Successfully retrieved the network information.", info)
 
 		#
 	def convert_dns(self, dns, timeout=3):
 		response = self.ping(dns, timeout=timeout)
 		if response["error"] != None: return response
 		if response["ip"] == None: 
-			return r3sponse.error(f"Failed to convert dns [{dns}].")
-		return r3sponse.success(f"Successfully converted dns [{dns}].", {
+			return Response.error(f"Failed to convert dns [{dns}].")
+		return Response.success(f"Successfully converted dns [{dns}].", {
 			"ip":response["ip"]
 		})
 	def ping(self, ip, timeout=3):
@@ -79,7 +79,7 @@ class Network(object):
 			info["up"] = None
 
 		# success.
-		return r3sponse.success(f"Successfully pinged [{ip}].", info)
+		return Response.success(f"Successfully pinged [{ip}].", info)
 
 		#
 	# system functions.
@@ -110,10 +110,10 @@ class Network(object):
 		for i in range(10000):
 			port = start + i
 			if not self.port_in_use(port):
-				return r3sponse.success(f"Successfully found a free port.", {
+				return Response.success(f"Successfully found a free port.", {
 					"port":port,
 				})
-		return r3sponse.error(f"Unable to find a free port.")
+		return Response.error(f"Unable to find a free port.")
 		#
 
 # initialized classes.
